<?php
/**
 * The header for our theme
 *
 * This is the template that displays all of the <head> section and everything up until <div id="content">
 *
 * @link https://developer.wordpress.org/themes/basics/template-files/#template-partials
 *
 * @package blog_town
 */

?>
<!doctype html>
<html <?php language_attributes(); ?>>
<head>
	<meta charset="<?php bloginfo( 'charset' ); ?>">
	<meta name="viewport" content="width=device-width, initial-scale=1">
	<link rel="profile" href="https://gmpg.org/xfn/11">

	<?php wp_head(); ?>
</head>

<body <?php body_class(); ?>>
<?php wp_body_open(); ?>

<!-- Preloader start-->
<div class="preloader">
  <div class="loader-inner">
    <img src="<?php echo esc_url(get_template_directory_uri() . '/assets/img/preloaderimg.gif') ?>" alt="">
  </div>
</div>
<!-- Preloader end -->

<div id="page" class="site-wrapper site">
	<a class="skip-link screen-reader-text" href="#primary"><?php esc_html_e( 'Skip to content', 'blog-town' ); ?></a>

    <?php 
    $display_topheader = get_theme_mod('blog_town_top_header_display',true);
    $display_latest_posts = get_theme_mod('blog_town_latest_post_display',true);
    $display_date = get_theme_mod('blog_town_date_display',true);
    $show_socialicon = get_theme_mod('blog_town_header_social_icon_display',true);
    $facebook_url = get_theme_mod('blog_town_social_icon_fb_url','#');
    $twitter_url = get_theme_mod('blog_town_social_icon_twitter_url','#');
    $instagram_url = get_theme_mod('blog_town_social_icon_insta_url','#');
    $social_icon_target = get_theme_mod('blog_town_social_icon_target_display',true);
    ?>

		<!-- header -->
        <header class="header-area">  
            <?php if($display_topheader) { ?>
            <div class="header-top second-header d-none d-lg-block">
                <div class="container">
                    <div class="row align-items-center">    
                        <div class="col-lg-8 col-md-6 d-none d-md-block">
                        <?php if($display_latest_posts) { ?>  
                            <div class="header-trending">
                                <div class="row">
                                    <div class="col-lg-2"><div class="h-btn"><span class="icon"></span> Trending</div></div>
                                    <div class="col-lg-10">
                                        <div id="newsIndicators" class="carousel slide col-11" data-ride="carousel">
                                            <div class="carousel-inner">
                                    <?php

                                    $args = array( 'posts_per_page' => 5, 'meta_key' => 'post_views_count', 'orderby' => 'meta_value_num', 'order' => 'DESC'  );

                                    $the_query = new WP_Query( $args );

                                    $c = 0;
                                    $class = '';
                                    if ($the_query->have_posts()) : while ($the_query->have_posts()) : $the_query->the_post();

                                         if ( $c == "0" )
                                         $class = ' active';
                                         else
                                         $class=''; 
                                    ?>
                                                <div class="carousel-item <?php echo esc_attr($class); ?>"> 
                                                    <a href="<?php the_permalink(); ?>"><?php the_title(); ?></a>
                                                </div>
                                                <?php 
                                                $c++;
                                       endwhile; endif;
                                       wp_reset_postdata();
                                    ?>
                                            </div>  
                                            
                                        </div>
                                    </div>
                                </div>
                                 
                            </div>
                        <?php } ?>
                        </div>
                        
                         <div class="col-lg-4 col-md-6 d-none d-lg-block">
                        <?php
                        if($display_date) {
                        ?>
                             <div class="top-btn"><i class="fal fa-calendar-alt"></i><?php echo esc_html(date("D, F j, Y")); ?></div>
                        <?php } ?>
                        </div>
                    </div>
                </div>
            </div>     
        <?php } ?>
            <div id="header-sticky" class="menu-area <?php if(is_user_logged_in()) { ?> blog-town-user <?php } ?>">
                <div class="container">
                    <div class="primary-menu">
                        <div class="row align-items-center">
                            <div class="col-xl-3 col-lg-3">
                                <div class="logo">
                                    <?php
                                    // Site Custom Logo
                                    if ( function_exists( 'the_custom_logo' ) ) {
                                        the_custom_logo();
                                    }
                                    ?> 

                                    
        
                                    <h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" title="<?php echo esc_attr( get_bloginfo( 'name', 'display' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
                                    
                                    
                                    <?php
                                    $description = get_bloginfo( 'description', 'display' );
                                    if ( $description || is_customize_preview() ) :
                                    ?>
                                    <p class="site-description">
                                        <?php echo esc_html( $description ); ?>
                                    </p>
                                    <?php endif; ?>
                    
                                    

                                </div>
                            </div>
                            <div class="col-xl-7 col-lg-6">

                                <nav id="site-navigation" class="main-navigation">
                                    <button class="toggle-button" data-toggle-target=".main-menu-modal" data-toggle-body-class="showing-main-menu-modal" aria-expanded="false" data-set-focus=".close-main-nav-toggle">
                                    <div class="toggle-text"></div>
                                        <span class="toggle-bar"></span>
                                        <span class="toggle-bar"></span>
                                        <span class="toggle-bar"></span>
                                    </button>
                                    <div class="primary-menu-list main-menu-modal cover-modal" data-modal-target-string=".main-menu-modal">
                                    <button class="close close-main-nav-toggle" data-toggle-target=".main-menu-modal" data-toggle-body-class="showing-main-menu-modal" aria-expanded="false" data-set-focus=".main-menu-modal"></button>
                                        <div class="mobile-menu" aria-label="<?php esc_attr_e( 'Mobile', 'blog-town' ); ?>">
                                        <?php
                                        wp_nav_menu( array(
                                        'theme_location' => 'primary',
                                        'menu_id'        => 'primary-menu',
                                        'menu_class'     => 'nav-menu main-menu-modal',
                                        
                                        ) );
                                        ?>
                                        </div>
                                    </div>
                                </nav><!-- #site-navigation -->
                            </div>   
                            <?php if($show_socialicon) { ?>
                            <div class="col-xl-2 col-lg-3 d-none d-lg-block mt-20 mb-20">
                                 <div class="header-social text-right">
                                    <span>

                                        <?php if($facebook_url != "") { ?>
                                        <a href="<?php echo esc_url($facebook_url);?>" <?php if($social_icon_target) { ?> target="_blank" <?php } ?> title="Facebook"><i class="fab fa-facebook-f"></i></a>
                                        <?php } ?>

                                        <?php if($twitter_url != "") { ?>
                                        <a href="<?php echo esc_url($twitter_url); ?>" <?php if($social_icon_target) { ?> target="_blank" <?php } ?> title="Twitter"><i class="fab fa-twitter"></i></a>
                                        <?php } ?>

                                        <?php if($instagram_url != "") { ?>
                                        <a href="<?php echo esc_url($instagram_url);?>" <?php if($social_icon_target) { ?> target="_blank" <?php } ?> title="Instagram"><i class="fab fa-instagram"></i></a>
                                        <?php } ?>
                                        
                                    </span>                    
                                                           
                                </div>
                                 
                            </div>
                            <?php } ?>
                            
                                <div class="col-12">
                                    <div class="mobile-menu"></div>
                                </div>
                        </div>
                    </div>
                </div>
            </div>
        </header>
        <!-- header-end -->
        <main id="primary" class="site-main">
