<?php
/**
 * Functions which enhance the theme by hooking into WordPress
 *
 * @package blog_town
 */

/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
function blog_town_body_classes( $classes ) {
	// Adds a class of hfeed to non-singular pages.
	if ( ! is_singular() ) {
		$classes[] = 'hfeed';
	}

	// Adds a class of no-sidebar when there is no sidebar present.
	if ( ! is_active_sidebar( 'sidebar-main' ) ) {
		$classes[] = 'no-sidebar';
	}

	// Theme Layout (wide|box)
	$classes[] = 'has-' . get_theme_mod('blog_town_theme_layout') . '-layout';

	return $classes;
}
add_filter( 'body_class', 'blog_town_body_classes' );

/**
 * Add a pingback url auto-discovery header for single posts, pages, or attachments.
 */
function blog_town_pingback_header() {
	if ( is_singular() && pings_open() ) {
		printf( '<link rel="pingback" href="%s">', esc_url( get_bloginfo( 'pingback_url' ) ) );
	}
}
add_action( 'wp_head', 'blog_town_pingback_header' );

function blog_town_breadcrumb(){
	if ( is_archive() ) {
	  the_archive_title( '<h2 class="banner-heading">', '</h2>' );
	}
	 elseif(is_search()){

	  echo  esc_html__('Search Results For ', 'blog-town') . ' " ' . get_search_query() . ' "';

	 }elseif ( is_404() ) {
	  echo  esc_html__('Nothing Found ', 'blog-town');
	 }
	 else
	 {
	 echo esc_html( get_the_title() );
	 } 
                                  
}